@@ -138,7 +138,7 @@ def test_score2(h, i):
 def get_eq_info():
     dc_url = "https://api.p2pquake.net/v2/jma/quake?limit=1"
     resp = requests.get(dc_url)
-    ql = loads(r.read())
+    ql = loads(resp.text)
     q = ql[0]
     return q.get("earthquake", {})
 
